NotCopy

Struct NotCopy 

#[repr(transparent)]
pub struct NotCopy<T>(pub T);
This type exists for one purpose and one purpose only. To help you ensure you’re mutating the correct thing, and not mutating a copy. Put Copy types in here to rob them of their Copy implementation.

This wrapper tries to be transparent in every way, of course it can’t implement every trait in existence, but we’ll try to get the important ones. Crate feature “serde” will include Serialize and Deserialize.

Major omissions from the trait implementations include common math traits, because consuming a NotCopy usually isn’t helpful, and those traits consume. However, traits such as AddAssign are implemented because they’re just a mutation.

Tuple Fields

0: T